@@ -27,7 +27,7 @@
 
 package Config::Model::Value ;
 {
-  $Config::Model::Value::VERSION = '1.260';
+  $Config::Model::Value::VERSION = '1.261';
 }
 use warnings ;
 use strict;
@@ -53,7 +53,7 @@ Config::Model::Value - Strongly typed configuration value
 
 =head1 VERSION
 
-version 1.260
+version 1.261
 
 =head1 SYNOPSIS
 
@@ -156,11 +156,17 @@ From the lowest default level to the "highest":
 
 =item *
 
-C<upstream_default>: The value is knows in the application, but is not
+C<upstream_default>: The value is known in the application, but is not
 written in the configuration file.
 
 =item *
 
+C<layered>: The value is known by the application through another
+mean (e.g. an included configuration file), but is not written in the 
+configuration file.
+
+=item *
+
 C<default>: The value is known by the model, but not by the
 application. This value must be written in the configuration file.
 
@@ -207,7 +213,14 @@ Specify the default value (optional)
 
 =item upstream_default
 
-Specify a built in default value (optional)
+Specify a built in default value (optional). I.e a value known by the application
+which does not need to be written in the configuration file.
+
+=item write_as
+
+Array ref. Reserved for boolean value. Specify how to write a boolean value. 
+Default is C<[0,1]> which may not be the most readable. C<write_as> can be 
+specified as C<['false','true']> or C<['no','yes']>. 
 
 =cut
 
@@ -508,7 +521,7 @@ sub setup_enum_choice {
     map {
 	delete $self->{$_}
 	  if (defined  $self->{$_} and not $self->check(value => $self->{$_}, quiet => 1)) ;
-    } qw/data preset/;
+    } qw/data preset layered/;
 }
 
 =item match
@@ -753,7 +766,7 @@ my @warp_accessible_params =  qw/min max mandatory default
 				 warn assert warn_unless warn_if_match warn_unless_match/ ;
 
 my @accessible_params =  (@warp_accessible_params, 
-			  qw/index_value element_name value_type
+			  qw/index_value element_name value_type write_as
 			     refer_to computed_refer_to replace_follow/ ) ;
 
 my @allowed_warp_params = (@warp_accessible_params, qw/level experience help/);
@@ -852,7 +865,8 @@ sub set_properties {
 
 
     map { $self->{$_} =  delete $args{$_} if defined $args{$_} }
-      qw/min max mandatory replace warn replace_follow assert warn_unless/ ;
+      qw/min max mandatory replace warn replace_follow assert warn_unless
+        write_as/ ;
 
     $self->set_help           ( \%args );
     $self->set_value_type     ( \%args );
@@ -868,12 +882,16 @@ sub set_properties {
     # cannot be warped
     $self->set_migrate_from   ( \%args ) if defined $args{migrate_from};
 
-    Config::Model::Exception::Model
-	-> throw (
-		  object => $self,
-		  error => "Unexpected parameters: ".join(' ', keys %args )
-		 ) 
-	  if scalar keys %args ;
+    Config::Model::Exception::Model -> throw (
+        object => $self,
+	error => "write_as is allowed only with boolean values"
+    ) if defined $self->{write_as} and $self->{value_type} ne 'boolean';
+
+
+    Config::Model::Exception::Model -> throw (
+        object => $self,
+	error => "Unexpected parameters: ".join(' ', keys %args )
+    ) if scalar keys %args ;
 
     if (defined $self->{warp_these_objects}) {
         my $value = $self->_fetch_no_check ;
@@ -948,6 +966,7 @@ sub set_value_type {
         # convert any value to boolean
         $self->{data} = $self->{data} ? 1 : 0 if defined $self->{data};
         $self->{preset} = $self->{preset} ? 1 : 0 if defined $self->{preset};
+        $self->{layered} = $self->{layered} ? 1 : 0 if defined $self->{layered};
     }
     elsif (   $value_type eq 'reference' 
 	   or $value_type eq 'enum' 
@@ -1709,7 +1728,10 @@ sub store {
 
     # we let store the value even if wrong when check is disabled
     if ($ok or $check eq 'no') {
-	if ($self->instance->preset) {
+        if ($self->instance->layered) {
+	    $self->{layered} = $value ;
+	} 
+	elsif ($self->instance->preset) {
 	    $self->{preset} = $value ;
 	} 
 	else {
@@ -1872,14 +1894,14 @@ sub fetch_custom {
 
     no warnings "uninitialized" ;
     my $data = $self->_fetch_no_check ;
-
-    return ($data ne $std_value) ? $data : undef ;
+    my $v = ($data ne $std_value) ? $data : undef ; 
+    return $self->map_write_as($v) ;
 }
 
 =head2 fetch_standard
 
 Returns the standard value as defined by the configuration model. The
-standard value can be either a preset value, a computed value, a
+standard value can be either a preset value, a layered value, a computed value, a
 default value or a built-in default value.
 
 =cut
@@ -1887,7 +1909,10 @@ default value or a built-in default value.
 sub fetch_standard {
     my $self = shift ;
     my $pre_fetch = $self->_pre_fetch ;
-    return defined $pre_fetch ? $pre_fetch : $self->{upstream_default} ;
+    my $v = defined $pre_fetch       ? $pre_fetch 
+          : defined $self->{layered} ? $self->{layered}
+          :                            $self->{upstream_default} ;
+    return $self->map_write_as($v) ;
 }
 
 sub _init {
@@ -1904,6 +1929,7 @@ sub _init {
     }
 }
 
+# returns something that needs to be written to config file
 sub _pre_fetch {
     my ($self, $mode, $check) = @_ ;
 
@@ -1946,14 +1972,17 @@ my %old_mode = ( built_in => 'upstream_default',
 
 my %accept_mode = map { ( $_ => 1) } 
                       qw/custom standard preset default upstream_default
-			non_upstream_default allow_undef/;
+			layered non_upstream_default allow_undef/;
 
 sub _fetch {
     my ($self, $mode, $check) = @_ ;
     $logger->debug("called for ".$self->location) if $logger->is_debug ;
 
     # always call to perform submit_to_warp
-    my $std = $self->_pre_fetch($mode, $check) ;
+    my $pref = $self->_pre_fetch($mode, $check) ;
+    my $known_upstream = defined $self->{layered} ? $self->{layered}
+                       :                            $self->{upstream_default} ;
+    my $std = defined $pref ? $pref : $known_upstream ;
     my $data = $self->{data} ;
 
     if (not defined $data and defined $self->{_migrate_from}) {
@@ -1976,7 +2005,8 @@ sub _fetch {
     if ($mode eq 'custom') {
 	no warnings "uninitialized" ;
 	my $cust ;
-	$cust = $data if $data ne $std and $data ne $self->{upstream_default} ;
+	$cust = $data if $data ne $pref and $data ne $self->{upstream_default} 
+            and $data ne $self->{layered};
         $logger->debug("done in custom mode for ".$self->location) 
             if $logger->is_debug ;
 	return $cust;
@@ -1985,7 +2015,7 @@ sub _fetch {
     if ($mode eq 'non_upstream_default') {
 	no warnings "uninitialized" ;
 	my $nbu = defined $data && $data ne $self->{upstream_default} ? $data 
-	        : defined $std  && $std  ne $self->{upstream_default} ? $std 
+	        : defined $pref && $pref ne $self->{upstream_default} ? $pref 
                 :                                                      undef ;
 
         $logger->debug("done in non_upstream_default mode for ".$self->location)
@@ -1996,13 +2026,13 @@ sub _fetch {
     $logger->debug("done in $mode mode for ".$self->location) 
         if $logger->is_debug ;
 
-    return $mode eq 'preset'                   ? $self->{preset}
-         : $mode eq 'default'                  ? $self->{default}
-         : $mode eq 'standard' && defined $std ? $std 
-         : $mode eq 'standard'                 ? $self->{upstream_default}
-	 : $mode eq 'upstream_default'         ? $self->{upstream_default}
-	 : defined $data                       ? $data
-         :                                       $std ;
+    return $mode eq 'preset'                    ? $self->{preset}
+         : $mode eq 'default'                   ? $self->{default}
+         : $mode eq 'standard'                  ? $std
+	 : $mode eq 'layered'                   ? $self->{layered}
+	 : $mode eq 'upstream_default'          ? $self->{upstream_default}
+	 : defined $data                        ? $data
+         :                                        $pref ;
 
 }
 
@@ -2086,6 +2116,11 @@ The preset or computed or default or built in value.
 
 The default value (defined by the configuration model)
 
+=item layered
+
+The value found in included files (treated in layered mode: values specified
+there are handled as upstream default values). E.g. like in multistrap config.
+
 =item upstream_default
 
 The upstream_default value. (defined by the configuration model)
@@ -2143,13 +2178,12 @@ sub fetch {
     $ok = $self->check(value => $value, silent => $silent, mode => $mode ) 
         if $mode eq '' or $mode eq 'custom' ;
 
-
     $logger->debug( "(almost) done for " . $self->location )
       if $logger->is_debug;
 
     # check validity (all modes)
     if ( $ok or $check eq 'no' ) {
-        return $value;
+        return $self->map_write_as($value);
     }
     elsif ( $check eq 'skip' ) {
         my $msg = $self->error_msg;
@@ -2166,6 +2200,14 @@ sub fetch {
     #return $value;    # undef in fact
 }
 
+sub map_write_as {
+    my ($self,$v) = @_ ;
+    return unless defined $v ;
+    return $v unless $self->{write_as};
+    return $v unless $self->value_type eq 'boolean';
+    return $self->{write_as}[$v] ;
+}
+
 =head2 user_value
 
 Returns the value entered by the user. Does not use the default or
@@ -2186,9 +2228,50 @@ preset mode.
 =cut
 
 sub fetch_preset {
-    return shift->{preset} ;
+    my $self= shift ;
+    return $self->map_write_as($self->{preset}) ;
 }
 
+=head2 clear_preset
+
+Delete the preset value. (Even out of preset mode). Returns true if other data 
+are still stored in the value (layered or user data). Returns false otherwise.
+
+=cut
+
+sub clear_preset {
+    my $self= shift ;
+    delete $self->{preset} ;
+    return defined $self->{layered} || defined $self->{data} ;
+}
+
+=head2 fetch_layered
+
+Returns the value entered in layered mode. Does not use the default or
+computed value. Returns undef unless a value was actually stored in
+layered mode.
+
+=cut
+
+sub fetch_layered {
+    my $self= shift ;
+    return $self->map_write_as($self->{layered}) ;
+}
+
+=head2 clear_layered
+
+Delete the layered value. (Even out of layered mode). Returns true if other data 
+are still stored in the value (layered or user data). Returns false otherwise.
+
+=cut
+
+sub clear_layered {
+    my $self= shift ;
+    delete $self->{layered} ;
+    return defined $self->{preset} || defined $self->{data} ;
+}
+
+
 
 =head2 get( path => ..., mode => ... ,  check => ... )
 
